@@ -23,6 +23,7 @@ pub struct SlackMessageOrigin {
 pub struct SlackMessageContent {
     pub text: Option<String>,
     pub blocks: Option<Vec<SlackBlock>>,
+    pub attachments: Option<Vec<SlackMessageAttachment>>,
 }
 
 #[skip_serializing_none]
@@ -79,3 +80,26 @@ pub enum SlackMessageResponseType {
     #[serde(rename = "ephemeral")]
     Ephemeral,
 }
+
+// This model is not well typed since Slack message attachments are deprecated
+// Please avoid using this if you can
+#[skip_serializing_none]
+#[derive(Debug, PartialEq, Clone, Serialize, Deserialize, Builder)]
+pub struct SlackMessageAttachment {
+    pub id: Option<i64>,
+    pub color: Option<String>,
+    pub fallback: Option<String>,
+    pub title: Option<String>,
+    pub fields: Option<Vec<SlackMessageAttachmentFieldObject>>,
+    pub mrkdwn_in: Option<Vec<String>>,
+}
+
+// This model is not well typed since Slack message attachments are deprecated
+// Please avoid using this if you can
+#[skip_serializing_none]
+#[derive(Debug, PartialEq, Clone, Serialize, Deserialize, Builder)]
+pub struct SlackMessageAttachmentFieldObject {
+    pub title: Option<String>,
+    pub value: Option<String>,
+    pub short: Option<bool>,
+}
